#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['bowtie', 'bowtie.feedback', 'bowtie.tests']

package_data = \
{'': ['*'],
 'bowtie': ['src/*',
            'src/node_modules/*',
            'src/node_modules/.bin/*',
            'src/node_modules/abs/*',
            'src/node_modules/abs/lib/*',
            'src/node_modules/ansi-regex/*',
            'src/node_modules/ansi-styles/*',
            'src/node_modules/anymatch/*',
            'src/node_modules/arr-diff/*',
            'src/node_modules/arr-flatten/*',
            'src/node_modules/array-unique/*',
            'src/node_modules/async-each/*',
            'src/node_modules/babel-cli/*',
            'src/node_modules/babel-cli/bin/*',
            'src/node_modules/babel-cli/lib/*',
            'src/node_modules/babel-cli/lib/babel/*',
            'src/node_modules/babel-cli/node_modules/*',
            'src/node_modules/babel-cli/node_modules/babel-core/*',
            'src/node_modules/babel-cli/node_modules/babel-core/lib/*',
            'src/node_modules/babel-cli/node_modules/babel-core/lib/api/*',
            'src/node_modules/babel-cli/node_modules/babel-core/lib/helpers/*',
            'src/node_modules/babel-cli/node_modules/babel-core/lib/tools/*',
            'src/node_modules/babel-cli/node_modules/babel-core/lib/transformation/*',
            'src/node_modules/babel-cli/node_modules/babel-core/lib/transformation/file/*',
            'src/node_modules/babel-cli/node_modules/babel-core/lib/transformation/file/options/*',
            'src/node_modules/babel-cli/node_modules/babel-core/lib/transformation/internal-plugins/*',
            'src/node_modules/babel-cli/node_modules/babel-polyfill/*',
            'src/node_modules/babel-cli/node_modules/babel-polyfill/dist/*',
            'src/node_modules/babel-cli/node_modules/babel-polyfill/lib/*',
            'src/node_modules/babel-cli/node_modules/babel-polyfill/scripts/*',
            'src/node_modules/babel-cli/node_modules/core-js/*',
            'src/node_modules/babel-cli/node_modules/core-js/build/*',
            'src/node_modules/babel-cli/node_modules/core-js/client/*',
            'src/node_modules/babel-cli/node_modules/core-js/core/*',
            'src/node_modules/babel-cli/node_modules/core-js/es5/*',
            'src/node_modules/babel-cli/node_modules/core-js/es6/*',
            'src/node_modules/babel-cli/node_modules/core-js/es7/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/array/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/array/virtual/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/date/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/dom-collections/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/error/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/function/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/function/virtual/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/json/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/map/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/math/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/number/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/number/virtual/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/object/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/promise/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/reflect/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/regexp/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/set/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/string/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/string/virtual/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/symbol/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/system/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/typed/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/weak-map/*',
            'src/node_modules/babel-cli/node_modules/core-js/fn/weak-set/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/core/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/es5/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/es6/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/es7/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/array/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/array/virtual/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/date/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/dom-collections/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/error/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/function/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/function/virtual/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/json/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/map/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/math/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/number/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/number/virtual/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/object/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/promise/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/reflect/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/regexp/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/set/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/string/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/string/virtual/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/symbol/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/system/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/typed/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/weak-map/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/fn/weak-set/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/modules/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/stage/*',
            'src/node_modules/babel-cli/node_modules/core-js/library/web/*',
            'src/node_modules/babel-cli/node_modules/core-js/modules/*',
            'src/node_modules/babel-cli/node_modules/core-js/modules/library/*',
            'src/node_modules/babel-cli/node_modules/core-js/stage/*',
            'src/node_modules/babel-cli/node_modules/core-js/web/*',
            'src/node_modules/babel-cli/node_modules/regenerator-runtime/*',
            'src/node_modules/babel-cli/scripts/*',
            'src/node_modules/babel-code-frame/*',
            'src/node_modules/babel-code-frame/lib/*',
            'src/node_modules/babel-generator/*',
            'src/node_modules/babel-generator/lib/*',
            'src/node_modules/babel-generator/lib/generators/*',
            'src/node_modules/babel-generator/lib/node/*',
            'src/node_modules/babel-helper-bindify-decorators/*',
            'src/node_modules/babel-helper-bindify-decorators/lib/*',
            'src/node_modules/babel-helper-builder-binary-assignment-operator-visitor/*',
            'src/node_modules/babel-helper-builder-binary-assignment-operator-visitor/lib/*',
            'src/node_modules/babel-helper-builder-react-jsx/*',
            'src/node_modules/babel-helper-builder-react-jsx/lib/*',
            'src/node_modules/babel-helper-call-delegate/*',
            'src/node_modules/babel-helper-call-delegate/lib/*',
            'src/node_modules/babel-helper-define-map/*',
            'src/node_modules/babel-helper-define-map/lib/*',
            'src/node_modules/babel-helper-explode-assignable-expression/*',
            'src/node_modules/babel-helper-explode-assignable-expression/lib/*',
            'src/node_modules/babel-helper-explode-class/*',
            'src/node_modules/babel-helper-explode-class/lib/*',
            'src/node_modules/babel-helper-function-name/*',
            'src/node_modules/babel-helper-function-name/lib/*',
            'src/node_modules/babel-helper-get-function-arity/*',
            'src/node_modules/babel-helper-get-function-arity/lib/*',
            'src/node_modules/babel-helper-hoist-variables/*',
            'src/node_modules/babel-helper-hoist-variables/lib/*',
            'src/node_modules/babel-helper-optimise-call-expression/*',
            'src/node_modules/babel-helper-optimise-call-expression/lib/*',
            'src/node_modules/babel-helper-regex/*',
            'src/node_modules/babel-helper-regex/lib/*',
            'src/node_modules/babel-helper-remap-async-to-generator/*',
            'src/node_modules/babel-helper-remap-async-to-generator/lib/*',
            'src/node_modules/babel-helper-replace-supers/*',
            'src/node_modules/babel-helper-replace-supers/lib/*',
            'src/node_modules/babel-helpers/*',
            'src/node_modules/babel-helpers/lib/*',
            'src/node_modules/babel-messages/*',
            'src/node_modules/babel-messages/lib/*',
            'src/node_modules/babel-plugin-check-es2015-constants/*',
            'src/node_modules/babel-plugin-check-es2015-constants/lib/*',
            'src/node_modules/babel-plugin-syntax-async-functions/*',
            'src/node_modules/babel-plugin-syntax-async-functions/lib/*',
            'src/node_modules/babel-plugin-syntax-async-generators/*',
            'src/node_modules/babel-plugin-syntax-async-generators/lib/*',
            'src/node_modules/babel-plugin-syntax-class-constructor-call/*',
            'src/node_modules/babel-plugin-syntax-class-constructor-call/lib/*',
            'src/node_modules/babel-plugin-syntax-class-properties/*',
            'src/node_modules/babel-plugin-syntax-class-properties/lib/*',
            'src/node_modules/babel-plugin-syntax-decorators/*',
            'src/node_modules/babel-plugin-syntax-decorators/lib/*',
            'src/node_modules/babel-plugin-syntax-do-expressions/*',
            'src/node_modules/babel-plugin-syntax-do-expressions/lib/*',
            'src/node_modules/babel-plugin-syntax-dynamic-import/*',
            'src/node_modules/babel-plugin-syntax-dynamic-import/lib/*',
            'src/node_modules/babel-plugin-syntax-exponentiation-operator/*',
            'src/node_modules/babel-plugin-syntax-exponentiation-operator/lib/*',
            'src/node_modules/babel-plugin-syntax-export-extensions/*',
            'src/node_modules/babel-plugin-syntax-export-extensions/lib/*',
            'src/node_modules/babel-plugin-syntax-flow/*',
            'src/node_modules/babel-plugin-syntax-flow/lib/*',
            'src/node_modules/babel-plugin-syntax-function-bind/*',
            'src/node_modules/babel-plugin-syntax-function-bind/lib/*',
            'src/node_modules/babel-plugin-syntax-jsx/*',
            'src/node_modules/babel-plugin-syntax-jsx/lib/*',
            'src/node_modules/babel-plugin-syntax-object-rest-spread/*',
            'src/node_modules/babel-plugin-syntax-object-rest-spread/lib/*',
            'src/node_modules/babel-plugin-syntax-trailing-function-commas/*',
            'src/node_modules/babel-plugin-syntax-trailing-function-commas/lib/*',
            'src/node_modules/babel-plugin-transform-async-generator-functions/*',
            'src/node_modules/babel-plugin-transform-async-generator-functions/lib/*',
            'src/node_modules/babel-plugin-transform-async-to-generator/*',
            'src/node_modules/babel-plugin-transform-async-to-generator/lib/*',
            'src/node_modules/babel-plugin-transform-class-constructor-call/*',
            'src/node_modules/babel-plugin-transform-class-constructor-call/lib/*',
            'src/node_modules/babel-plugin-transform-class-properties/*',
            'src/node_modules/babel-plugin-transform-class-properties/lib/*',
            'src/node_modules/babel-plugin-transform-decorators/*',
            'src/node_modules/babel-plugin-transform-decorators/lib/*',
            'src/node_modules/babel-plugin-transform-do-expressions/*',
            'src/node_modules/babel-plugin-transform-do-expressions/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-arrow-functions/*',
            'src/node_modules/babel-plugin-transform-es2015-arrow-functions/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-block-scoped-functions/*',
            'src/node_modules/babel-plugin-transform-es2015-block-scoped-functions/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-block-scoping/*',
            'src/node_modules/babel-plugin-transform-es2015-block-scoping/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-classes/*',
            'src/node_modules/babel-plugin-transform-es2015-classes/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-classes/lib/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-computed-properties/*',
            'src/node_modules/babel-plugin-transform-es2015-computed-properties/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-destructuring/*',
            'src/node_modules/babel-plugin-transform-es2015-destructuring/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-duplicate-keys/*',
            'src/node_modules/babel-plugin-transform-es2015-duplicate-keys/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-for-of/*',
            'src/node_modules/babel-plugin-transform-es2015-for-of/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-function-name/*',
            'src/node_modules/babel-plugin-transform-es2015-function-name/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-literals/*',
            'src/node_modules/babel-plugin-transform-es2015-literals/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-modules-amd/*',
            'src/node_modules/babel-plugin-transform-es2015-modules-amd/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-modules-commonjs/*',
            'src/node_modules/babel-plugin-transform-es2015-modules-commonjs/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-modules-systemjs/*',
            'src/node_modules/babel-plugin-transform-es2015-modules-systemjs/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-modules-umd/*',
            'src/node_modules/babel-plugin-transform-es2015-modules-umd/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-object-super/*',
            'src/node_modules/babel-plugin-transform-es2015-object-super/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-parameters/*',
            'src/node_modules/babel-plugin-transform-es2015-parameters/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-shorthand-properties/*',
            'src/node_modules/babel-plugin-transform-es2015-shorthand-properties/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-spread/*',
            'src/node_modules/babel-plugin-transform-es2015-spread/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-sticky-regex/*',
            'src/node_modules/babel-plugin-transform-es2015-sticky-regex/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-template-literals/*',
            'src/node_modules/babel-plugin-transform-es2015-template-literals/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-typeof-symbol/*',
            'src/node_modules/babel-plugin-transform-es2015-typeof-symbol/lib/*',
            'src/node_modules/babel-plugin-transform-es2015-unicode-regex/*',
            'src/node_modules/babel-plugin-transform-es2015-unicode-regex/lib/*',
            'src/node_modules/babel-plugin-transform-exponentiation-operator/*',
            'src/node_modules/babel-plugin-transform-exponentiation-operator/lib/*',
            'src/node_modules/babel-plugin-transform-export-extensions/*',
            'src/node_modules/babel-plugin-transform-export-extensions/lib/*',
            'src/node_modules/babel-plugin-transform-flow-strip-types/*',
            'src/node_modules/babel-plugin-transform-flow-strip-types/lib/*',
            'src/node_modules/babel-plugin-transform-function-bind/*',
            'src/node_modules/babel-plugin-transform-function-bind/lib/*',
            'src/node_modules/babel-plugin-transform-react-display-name/*',
            'src/node_modules/babel-plugin-transform-react-display-name/lib/*',
            'src/node_modules/babel-plugin-transform-react-jsx-self/*',
            'src/node_modules/babel-plugin-transform-react-jsx-self/lib/*',
            'src/node_modules/babel-plugin-transform-react-jsx-source/*',
            'src/node_modules/babel-plugin-transform-react-jsx-source/lib/*',
            'src/node_modules/babel-plugin-transform-react-jsx/*',
            'src/node_modules/babel-plugin-transform-react-jsx/lib/*',
            'src/node_modules/babel-plugin-transform-regenerator/*',
            'src/node_modules/babel-plugin-transform-regenerator/lib/*',
            'src/node_modules/babel-plugin-transform-strict-mode/*',
            'src/node_modules/babel-plugin-transform-strict-mode/lib/*',
            'src/node_modules/babel-preset-es2015/*',
            'src/node_modules/babel-preset-es2015/lib/*',
            'src/node_modules/babel-preset-flow/*',
            'src/node_modules/babel-preset-flow/lib/*',
            'src/node_modules/babel-preset-react/*',
            'src/node_modules/babel-preset-react/lib/*',
            'src/node_modules/babel-preset-stage-0/*',
            'src/node_modules/babel-preset-stage-0/lib/*',
            'src/node_modules/babel-preset-stage-1/*',
            'src/node_modules/babel-preset-stage-1/lib/*',
            'src/node_modules/babel-preset-stage-2/*',
            'src/node_modules/babel-preset-stage-2/lib/*',
            'src/node_modules/babel-preset-stage-3/*',
            'src/node_modules/babel-preset-stage-3/lib/*',
            'src/node_modules/babel-preset-stage-3/node_modules/*',
            'src/node_modules/babel-preset-stage-3/node_modules/babel-plugin-transform-object-rest-spread/*',
            'src/node_modules/babel-preset-stage-3/node_modules/babel-plugin-transform-object-rest-spread/lib/*',
            'src/node_modules/babel-register/*',
            'src/node_modules/babel-register/lib/*',
            'src/node_modules/babel-register/node_modules/*',
            'src/node_modules/babel-register/node_modules/babel-core/*',
            'src/node_modules/babel-register/node_modules/babel-core/lib/*',
            'src/node_modules/babel-register/node_modules/babel-core/lib/api/*',
            'src/node_modules/babel-register/node_modules/babel-core/lib/helpers/*',
            'src/node_modules/babel-register/node_modules/babel-core/lib/tools/*',
            'src/node_modules/babel-register/node_modules/babel-core/lib/transformation/*',
            'src/node_modules/babel-register/node_modules/babel-core/lib/transformation/file/*',
            'src/node_modules/babel-register/node_modules/babel-core/lib/transformation/file/options/*',
            'src/node_modules/babel-register/node_modules/babel-core/lib/transformation/internal-plugins/*',
            'src/node_modules/babel-register/node_modules/core-js/*',
            'src/node_modules/babel-register/node_modules/core-js/build/*',
            'src/node_modules/babel-register/node_modules/core-js/client/*',
            'src/node_modules/babel-register/node_modules/core-js/core/*',
            'src/node_modules/babel-register/node_modules/core-js/es5/*',
            'src/node_modules/babel-register/node_modules/core-js/es6/*',
            'src/node_modules/babel-register/node_modules/core-js/es7/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/array/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/array/virtual/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/date/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/dom-collections/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/error/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/function/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/function/virtual/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/json/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/map/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/math/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/number/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/number/virtual/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/object/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/promise/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/reflect/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/regexp/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/set/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/string/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/string/virtual/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/symbol/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/system/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/typed/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/weak-map/*',
            'src/node_modules/babel-register/node_modules/core-js/fn/weak-set/*',
            'src/node_modules/babel-register/node_modules/core-js/library/*',
            'src/node_modules/babel-register/node_modules/core-js/library/core/*',
            'src/node_modules/babel-register/node_modules/core-js/library/es5/*',
            'src/node_modules/babel-register/node_modules/core-js/library/es6/*',
            'src/node_modules/babel-register/node_modules/core-js/library/es7/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/array/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/array/virtual/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/date/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/dom-collections/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/error/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/function/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/function/virtual/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/json/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/map/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/math/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/number/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/number/virtual/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/object/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/promise/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/reflect/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/regexp/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/set/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/string/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/string/virtual/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/symbol/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/system/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/typed/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/weak-map/*',
            'src/node_modules/babel-register/node_modules/core-js/library/fn/weak-set/*',
            'src/node_modules/babel-register/node_modules/core-js/library/modules/*',
            'src/node_modules/babel-register/node_modules/core-js/library/stage/*',
            'src/node_modules/babel-register/node_modules/core-js/library/web/*',
            'src/node_modules/babel-register/node_modules/core-js/modules/*',
            'src/node_modules/babel-register/node_modules/core-js/modules/library/*',
            'src/node_modules/babel-register/node_modules/core-js/stage/*',
            'src/node_modules/babel-register/node_modules/core-js/web/*',
            'src/node_modules/babel-runtime/*',
            'src/node_modules/babel-runtime/core-js/*',
            'src/node_modules/babel-runtime/core-js/array/*',
            'src/node_modules/babel-runtime/core-js/error/*',
            'src/node_modules/babel-runtime/core-js/json/*',
            'src/node_modules/babel-runtime/core-js/math/*',
            'src/node_modules/babel-runtime/core-js/number/*',
            'src/node_modules/babel-runtime/core-js/object/*',
            'src/node_modules/babel-runtime/core-js/reflect/*',
            'src/node_modules/babel-runtime/core-js/regexp/*',
            'src/node_modules/babel-runtime/core-js/string/*',
            'src/node_modules/babel-runtime/core-js/symbol/*',
            'src/node_modules/babel-runtime/core-js/system/*',
            'src/node_modules/babel-runtime/helpers/*',
            'src/node_modules/babel-runtime/node_modules/*',
            'src/node_modules/babel-runtime/node_modules/core-js/*',
            'src/node_modules/babel-runtime/node_modules/core-js/build/*',
            'src/node_modules/babel-runtime/node_modules/core-js/client/*',
            'src/node_modules/babel-runtime/node_modules/core-js/core/*',
            'src/node_modules/babel-runtime/node_modules/core-js/es5/*',
            'src/node_modules/babel-runtime/node_modules/core-js/es6/*',
            'src/node_modules/babel-runtime/node_modules/core-js/es7/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/array/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/array/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/date/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/dom-collections/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/error/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/function/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/function/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/json/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/map/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/math/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/number/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/number/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/object/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/promise/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/reflect/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/regexp/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/set/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/string/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/string/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/symbol/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/system/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/typed/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/weak-map/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/weak-set/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/core/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/es5/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/es6/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/es7/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/array/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/array/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/date/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/dom-collections/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/error/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/function/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/function/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/json/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/map/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/math/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/number/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/number/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/object/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/promise/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/reflect/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/regexp/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/set/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/string/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/string/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/symbol/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/system/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/typed/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/weak-map/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/weak-set/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/modules/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/stage/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/web/*',
            'src/node_modules/babel-runtime/node_modules/core-js/modules/*',
            'src/node_modules/babel-runtime/node_modules/core-js/modules/library/*',
            'src/node_modules/babel-runtime/node_modules/core-js/stage/*',
            'src/node_modules/babel-runtime/node_modules/core-js/web/*',
            'src/node_modules/babel-runtime/regenerator/*',
            'src/node_modules/babel-template/*',
            'src/node_modules/babel-template/lib/*',
            'src/node_modules/babel-traverse/*',
            'src/node_modules/babel-traverse/lib/*',
            'src/node_modules/babel-traverse/lib/path/*',
            'src/node_modules/babel-traverse/lib/path/inference/*',
            'src/node_modules/babel-traverse/lib/path/lib/*',
            'src/node_modules/babel-traverse/lib/scope/*',
            'src/node_modules/babel-traverse/lib/scope/lib/*',
            'src/node_modules/babel-types/*',
            'src/node_modules/babel-types/lib/*',
            'src/node_modules/babel-types/lib/definitions/*',
            'src/node_modules/babel/*',
            'src/node_modules/babel/lib/*',
            'src/node_modules/babylon/*',
            'src/node_modules/babylon/bin/*',
            'src/node_modules/babylon/lib/*',
            'src/node_modules/balanced-match/*',
            'src/node_modules/binary-extensions/*',
            'src/node_modules/brace-expansion/*',
            'src/node_modules/braces/*',
            'src/node_modules/builtin-modules/*',
            'src/node_modules/capture-stack-trace/*',
            'src/node_modules/chalk/*',
            'src/node_modules/chokidar/*',
            'src/node_modules/chokidar/lib/*',
            'src/node_modules/commander/*',
            'src/node_modules/commander/typings/*',
            'src/node_modules/concat-map/*',
            'src/node_modules/concat-map/example/*',
            'src/node_modules/concat-map/test/*',
            'src/node_modules/convert-source-map/*',
            'src/node_modules/core-util-is/*',
            'src/node_modules/core-util-is/lib/*',
            'src/node_modules/create-error-class/*',
            'src/node_modules/debug/*',
            'src/node_modules/debug/src/*',
            'src/node_modules/deep-extend/*',
            'src/node_modules/deep-extend/lib/*',
            'src/node_modules/deffy/*',
            'src/node_modules/deffy/lib/*',
            'src/node_modules/detect-indent/*',
            'src/node_modules/duplexer2/*',
            'src/node_modules/err/*',
            'src/node_modules/err/example/*',
            'src/node_modules/err/lib/*',
            'src/node_modules/error-ex/*',
            'src/node_modules/escape-string-regexp/*',
            'src/node_modules/esutils/*',
            'src/node_modules/esutils/lib/*',
            'src/node_modules/exec-limiter/*',
            'src/node_modules/exec-limiter/lib/*',
            'src/node_modules/expand-brackets/*',
            'src/node_modules/expand-range/*',
            'src/node_modules/extglob/*',
            'src/node_modules/filename-regex/*',
            'src/node_modules/fill-range/*',
            'src/node_modules/for-in/*',
            'src/node_modules/for-own/*',
            'src/node_modules/fs-readdir-recursive/*',
            'src/node_modules/fs.realpath/*',
            'src/node_modules/fsevents/*',
            'src/node_modules/fsevents/build/*',
            'src/node_modules/fsevents/build/Release/*',
            'src/node_modules/fsevents/build/Release/.deps/*',
            'src/node_modules/fsevents/build/Release/.deps/Release/*',
            'src/node_modules/fsevents/build/Release/.deps/Release/obj.target/*',
            'src/node_modules/fsevents/build/Release/.deps/Release/obj.target/fse/*',
            'src/node_modules/fsevents/build/Release/.deps/Users/*',
            'src/node_modules/fsevents/build/Release/.deps/Users/eshanker/*',
            'src/node_modules/fsevents/build/Release/.deps/Users/eshanker/Code/*',
            'src/node_modules/fsevents/build/Release/.deps/Users/eshanker/Code/fsevents/*',
            'src/node_modules/fsevents/build/Release/.deps/Users/eshanker/Code/fsevents/lib/*',
            'src/node_modules/fsevents/build/Release/.deps/Users/eshanker/Code/fsevents/lib/binding/*',
            'src/node_modules/fsevents/build/Release/.deps/Users/eshanker/Code/fsevents/lib/binding/Release/*',
            'src/node_modules/fsevents/build/Release/.deps/Users/eshanker/Code/fsevents/lib/binding/Release/node-v48-darwin-x64/*',
            'src/node_modules/fsevents/build/Release/obj.target/*',
            'src/node_modules/fsevents/build/Release/obj.target/fse/*',
            'src/node_modules/fsevents/build/stage/*',
            'src/node_modules/fsevents/build/stage/v1.1.2/*',
            'src/node_modules/fsevents/lib/*',
            'src/node_modules/fsevents/lib/binding/*',
            'src/node_modules/fsevents/lib/binding/Release/*',
            'src/node_modules/fsevents/lib/binding/Release/node-v11-darwin-x64/*',
            'src/node_modules/fsevents/lib/binding/Release/node-v46-darwin-x64/*',
            'src/node_modules/fsevents/lib/binding/Release/node-v47-darwin-x64/*',
            'src/node_modules/fsevents/lib/binding/Release/node-v48-darwin-x64/*',
            'src/node_modules/fsevents/lib/binding/Release/node-v57-darwin-x64/*',
            'src/node_modules/fsevents/lib/binding/Release/node-v59-darwin-x64/*',
            'src/node_modules/fsevents/node_modules/*',
            'src/node_modules/fsevents/node_modules/.bin/*',
            'src/node_modules/fsevents/node_modules/abbrev/*',
            'src/node_modules/fsevents/node_modules/ajv/*',
            'src/node_modules/fsevents/node_modules/ajv/dist/*',
            'src/node_modules/fsevents/node_modules/ajv/lib/*',
            'src/node_modules/fsevents/node_modules/ajv/lib/compile/*',
            'src/node_modules/fsevents/node_modules/ajv/lib/dot/*',
            'src/node_modules/fsevents/node_modules/ajv/lib/dot/v5/*',
            'src/node_modules/fsevents/node_modules/ajv/lib/dotjs/*',
            'src/node_modules/fsevents/node_modules/ajv/lib/refs/*',
            'src/node_modules/fsevents/node_modules/ajv/scripts/*',
            'src/node_modules/fsevents/node_modules/ansi-regex/*',
            'src/node_modules/fsevents/node_modules/aproba/*',
            'src/node_modules/fsevents/node_modules/are-we-there-yet/*',
            'src/node_modules/fsevents/node_modules/asn1/*',
            'src/node_modules/fsevents/node_modules/asn1/lib/*',
            'src/node_modules/fsevents/node_modules/asn1/lib/ber/*',
            'src/node_modules/fsevents/node_modules/asn1/tst/*',
            'src/node_modules/fsevents/node_modules/asn1/tst/ber/*',
            'src/node_modules/fsevents/node_modules/assert-plus/*',
            'src/node_modules/fsevents/node_modules/asynckit/*',
            'src/node_modules/fsevents/node_modules/asynckit/lib/*',
            'src/node_modules/fsevents/node_modules/aws-sign2/*',
            'src/node_modules/fsevents/node_modules/aws4/*',
            'src/node_modules/fsevents/node_modules/balanced-match/*',
            'src/node_modules/fsevents/node_modules/bcrypt-pbkdf/*',
            'src/node_modules/fsevents/node_modules/block-stream/*',
            'src/node_modules/fsevents/node_modules/boom/*',
            'src/node_modules/fsevents/node_modules/boom/images/*',
            'src/node_modules/fsevents/node_modules/boom/lib/*',
            'src/node_modules/fsevents/node_modules/boom/test/*',
            'src/node_modules/fsevents/node_modules/brace-expansion/*',
            'src/node_modules/fsevents/node_modules/buffer-shims/*',
            'src/node_modules/fsevents/node_modules/caseless/*',
            'src/node_modules/fsevents/node_modules/co/*',
            'src/node_modules/fsevents/node_modules/code-point-at/*',
            'src/node_modules/fsevents/node_modules/combined-stream/*',
            'src/node_modules/fsevents/node_modules/combined-stream/lib/*',
            'src/node_modules/fsevents/node_modules/concat-map/*',
            'src/node_modules/fsevents/node_modules/concat-map/example/*',
            'src/node_modules/fsevents/node_modules/concat-map/test/*',
            'src/node_modules/fsevents/node_modules/console-control-strings/*',
            'src/node_modules/fsevents/node_modules/core-util-is/*',
            'src/node_modules/fsevents/node_modules/core-util-is/lib/*',
            'src/node_modules/fsevents/node_modules/cryptiles/*',
            'src/node_modules/fsevents/node_modules/cryptiles/lib/*',
            'src/node_modules/fsevents/node_modules/cryptiles/test/*',
            'src/node_modules/fsevents/node_modules/dashdash/*',
            'src/node_modules/fsevents/node_modules/dashdash/etc/*',
            'src/node_modules/fsevents/node_modules/dashdash/lib/*',
            'src/node_modules/fsevents/node_modules/dashdash/node_modules/*',
            'src/node_modules/fsevents/node_modules/dashdash/node_modules/assert-plus/*',
            'src/node_modules/fsevents/node_modules/debug/*',
            'src/node_modules/fsevents/node_modules/debug/src/*',
            'src/node_modules/fsevents/node_modules/deep-extend/*',
            'src/node_modules/fsevents/node_modules/deep-extend/lib/*',
            'src/node_modules/fsevents/node_modules/delayed-stream/*',
            'src/node_modules/fsevents/node_modules/delayed-stream/lib/*',
            'src/node_modules/fsevents/node_modules/delegates/*',
            'src/node_modules/fsevents/node_modules/delegates/test/*',
            'src/node_modules/fsevents/node_modules/detect-libc/*',
            'src/node_modules/fsevents/node_modules/detect-libc/bin/*',
            'src/node_modules/fsevents/node_modules/detect-libc/lib/*',
            'src/node_modules/fsevents/node_modules/ecc-jsbn/*',
            'src/node_modules/fsevents/node_modules/ecc-jsbn/lib/*',
            'src/node_modules/fsevents/node_modules/extend/*',
            'src/node_modules/fsevents/node_modules/extsprintf/*',
            'src/node_modules/fsevents/node_modules/extsprintf/examples/*',
            'src/node_modules/fsevents/node_modules/extsprintf/lib/*',
            'src/node_modules/fsevents/node_modules/forever-agent/*',
            'src/node_modules/fsevents/node_modules/form-data/*',
            'src/node_modules/fsevents/node_modules/form-data/lib/*',
            'src/node_modules/fsevents/node_modules/fs.realpath/*',
            'src/node_modules/fsevents/node_modules/fstream-ignore/*',
            'src/node_modules/fsevents/node_modules/fstream/*',
            'src/node_modules/fsevents/node_modules/fstream/examples/*',
            'src/node_modules/fsevents/node_modules/fstream/lib/*',
            'src/node_modules/fsevents/node_modules/gauge/*',
            'src/node_modules/fsevents/node_modules/getpass/*',
            'src/node_modules/fsevents/node_modules/getpass/lib/*',
            'src/node_modules/fsevents/node_modules/getpass/node_modules/*',
            'src/node_modules/fsevents/node_modules/getpass/node_modules/assert-plus/*',
            'src/node_modules/fsevents/node_modules/glob/*',
            'src/node_modules/fsevents/node_modules/graceful-fs/*',
            'src/node_modules/fsevents/node_modules/har-schema/*',
            'src/node_modules/fsevents/node_modules/har-schema/lib/*',
            'src/node_modules/fsevents/node_modules/har-validator/*',
            'src/node_modules/fsevents/node_modules/har-validator/lib/*',
            'src/node_modules/fsevents/node_modules/har-validator/lib/browser/*',
            'src/node_modules/fsevents/node_modules/har-validator/lib/node4/*',
            'src/node_modules/fsevents/node_modules/har-validator/lib/node6/*',
            'src/node_modules/fsevents/node_modules/har-validator/lib/node7/*',
            'src/node_modules/fsevents/node_modules/har-validator/src/*',
            'src/node_modules/fsevents/node_modules/has-unicode/*',
            'src/node_modules/fsevents/node_modules/hawk/*',
            'src/node_modules/fsevents/node_modules/hawk/dist/*',
            'src/node_modules/fsevents/node_modules/hawk/example/*',
            'src/node_modules/fsevents/node_modules/hawk/images/*',
            'src/node_modules/fsevents/node_modules/hawk/lib/*',
            'src/node_modules/fsevents/node_modules/hawk/test/*',
            'src/node_modules/fsevents/node_modules/hoek/*',
            'src/node_modules/fsevents/node_modules/hoek/images/*',
            'src/node_modules/fsevents/node_modules/hoek/lib/*',
            'src/node_modules/fsevents/node_modules/hoek/test/*',
            'src/node_modules/fsevents/node_modules/hoek/test/modules/*',
            'src/node_modules/fsevents/node_modules/http-signature/*',
            'src/node_modules/fsevents/node_modules/http-signature/lib/*',
            'src/node_modules/fsevents/node_modules/inflight/*',
            'src/node_modules/fsevents/node_modules/inherits/*',
            'src/node_modules/fsevents/node_modules/ini/*',
            'src/node_modules/fsevents/node_modules/is-fullwidth-code-point/*',
            'src/node_modules/fsevents/node_modules/is-typedarray/*',
            'src/node_modules/fsevents/node_modules/isarray/*',
            'src/node_modules/fsevents/node_modules/isstream/*',
            'src/node_modules/fsevents/node_modules/jodid25519/*',
            'src/node_modules/fsevents/node_modules/jodid25519/lib/*',
            'src/node_modules/fsevents/node_modules/jsbn/*',
            'src/node_modules/fsevents/node_modules/json-schema/*',
            'src/node_modules/fsevents/node_modules/json-schema/draft-00/*',
            'src/node_modules/fsevents/node_modules/json-schema/draft-01/*',
            'src/node_modules/fsevents/node_modules/json-schema/draft-02/*',
            'src/node_modules/fsevents/node_modules/json-schema/draft-03/*',
            'src/node_modules/fsevents/node_modules/json-schema/draft-03/examples/*',
            'src/node_modules/fsevents/node_modules/json-schema/draft-04/*',
            'src/node_modules/fsevents/node_modules/json-schema/lib/*',
            'src/node_modules/fsevents/node_modules/json-schema/test/*',
            'src/node_modules/fsevents/node_modules/json-stable-stringify/*',
            'src/node_modules/fsevents/node_modules/json-stable-stringify/example/*',
            'src/node_modules/fsevents/node_modules/json-stable-stringify/test/*',
            'src/node_modules/fsevents/node_modules/json-stringify-safe/*',
            'src/node_modules/fsevents/node_modules/json-stringify-safe/test/*',
            'src/node_modules/fsevents/node_modules/jsonify/*',
            'src/node_modules/fsevents/node_modules/jsonify/lib/*',
            'src/node_modules/fsevents/node_modules/jsonify/test/*',
            'src/node_modules/fsevents/node_modules/jsprim/*',
            'src/node_modules/fsevents/node_modules/jsprim/lib/*',
            'src/node_modules/fsevents/node_modules/jsprim/node_modules/*',
            'src/node_modules/fsevents/node_modules/jsprim/node_modules/assert-plus/*',
            'src/node_modules/fsevents/node_modules/mime-db/*',
            'src/node_modules/fsevents/node_modules/mime-types/*',
            'src/node_modules/fsevents/node_modules/minimatch/*',
            'src/node_modules/fsevents/node_modules/minimist/*',
            'src/node_modules/fsevents/node_modules/minimist/example/*',
            'src/node_modules/fsevents/node_modules/minimist/test/*',
            'src/node_modules/fsevents/node_modules/mkdirp/*',
            'src/node_modules/fsevents/node_modules/mkdirp/bin/*',
            'src/node_modules/fsevents/node_modules/mkdirp/examples/*',
            'src/node_modules/fsevents/node_modules/mkdirp/test/*',
            'src/node_modules/fsevents/node_modules/ms/*',
            'src/node_modules/fsevents/node_modules/node-pre-gyp/*',
            'src/node_modules/fsevents/node_modules/node-pre-gyp/bin/*',
            'src/node_modules/fsevents/node_modules/node-pre-gyp/lib/*',
            'src/node_modules/fsevents/node_modules/node-pre-gyp/lib/util/*',
            'src/node_modules/fsevents/node_modules/node-pre-gyp/lib/util/nw-pre-gyp/*',
            'src/node_modules/fsevents/node_modules/nopt/*',
            'src/node_modules/fsevents/node_modules/nopt/bin/*',
            'src/node_modules/fsevents/node_modules/nopt/examples/*',
            'src/node_modules/fsevents/node_modules/nopt/lib/*',
            'src/node_modules/fsevents/node_modules/nopt/test/*',
            'src/node_modules/fsevents/node_modules/npmlog/*',
            'src/node_modules/fsevents/node_modules/number-is-nan/*',
            'src/node_modules/fsevents/node_modules/oauth-sign/*',
            'src/node_modules/fsevents/node_modules/object-assign/*',
            'src/node_modules/fsevents/node_modules/once/*',
            'src/node_modules/fsevents/node_modules/os-homedir/*',
            'src/node_modules/fsevents/node_modules/os-tmpdir/*',
            'src/node_modules/fsevents/node_modules/osenv/*',
            'src/node_modules/fsevents/node_modules/osenv/test/*',
            'src/node_modules/fsevents/node_modules/path-is-absolute/*',
            'src/node_modules/fsevents/node_modules/performance-now/*',
            'src/node_modules/fsevents/node_modules/performance-now/lib/*',
            'src/node_modules/fsevents/node_modules/performance-now/src/*',
            'src/node_modules/fsevents/node_modules/performance-now/test/*',
            'src/node_modules/fsevents/node_modules/process-nextick-args/*',
            'src/node_modules/fsevents/node_modules/punycode/*',
            'src/node_modules/fsevents/node_modules/qs/*',
            'src/node_modules/fsevents/node_modules/qs/dist/*',
            'src/node_modules/fsevents/node_modules/qs/lib/*',
            'src/node_modules/fsevents/node_modules/qs/test/*',
            'src/node_modules/fsevents/node_modules/rc/*',
            'src/node_modules/fsevents/node_modules/rc/lib/*',
            'src/node_modules/fsevents/node_modules/rc/node_modules/*',
            'src/node_modules/fsevents/node_modules/rc/node_modules/minimist/*',
            'src/node_modules/fsevents/node_modules/rc/node_modules/minimist/example/*',
            'src/node_modules/fsevents/node_modules/rc/node_modules/minimist/test/*',
            'src/node_modules/fsevents/node_modules/rc/test/*',
            'src/node_modules/fsevents/node_modules/readable-stream/*',
            'src/node_modules/fsevents/node_modules/readable-stream/doc/*',
            'src/node_modules/fsevents/node_modules/readable-stream/doc/wg-meetings/*',
            'src/node_modules/fsevents/node_modules/readable-stream/lib/*',
            'src/node_modules/fsevents/node_modules/readable-stream/lib/internal/*',
            'src/node_modules/fsevents/node_modules/readable-stream/lib/internal/streams/*',
            'src/node_modules/fsevents/node_modules/request/*',
            'src/node_modules/fsevents/node_modules/request/lib/*',
            'src/node_modules/fsevents/node_modules/rimraf/*',
            'src/node_modules/fsevents/node_modules/safe-buffer/*',
            'src/node_modules/fsevents/node_modules/semver/*',
            'src/node_modules/fsevents/node_modules/semver/bin/*',
            'src/node_modules/fsevents/node_modules/set-blocking/*',
            'src/node_modules/fsevents/node_modules/signal-exit/*',
            'src/node_modules/fsevents/node_modules/sntp/*',
            'src/node_modules/fsevents/node_modules/sntp/examples/*',
            'src/node_modules/fsevents/node_modules/sntp/lib/*',
            'src/node_modules/fsevents/node_modules/sntp/test/*',
            'src/node_modules/fsevents/node_modules/sshpk/*',
            'src/node_modules/fsevents/node_modules/sshpk/bin/*',
            'src/node_modules/fsevents/node_modules/sshpk/lib/*',
            'src/node_modules/fsevents/node_modules/sshpk/lib/formats/*',
            'src/node_modules/fsevents/node_modules/sshpk/man/*',
            'src/node_modules/fsevents/node_modules/sshpk/man/man1/*',
            'src/node_modules/fsevents/node_modules/sshpk/node_modules/*',
            'src/node_modules/fsevents/node_modules/sshpk/node_modules/assert-plus/*',
            'src/node_modules/fsevents/node_modules/string-width/*',
            'src/node_modules/fsevents/node_modules/string_decoder/*',
            'src/node_modules/fsevents/node_modules/string_decoder/lib/*',
            'src/node_modules/fsevents/node_modules/stringstream/*',
            'src/node_modules/fsevents/node_modules/strip-ansi/*',
            'src/node_modules/fsevents/node_modules/strip-json-comments/*',
            'src/node_modules/fsevents/node_modules/tar-pack/*',
            'src/node_modules/fsevents/node_modules/tar-pack/test/*',
            'src/node_modules/fsevents/node_modules/tar-pack/test/fixtures/*',
            'src/node_modules/fsevents/node_modules/tar-pack/test/fixtures/to-pack/*',
            'src/node_modules/fsevents/node_modules/tar/*',
            'src/node_modules/fsevents/node_modules/tar/examples/*',
            'src/node_modules/fsevents/node_modules/tar/lib/*',
            'src/node_modules/fsevents/node_modules/tar/test/*',
            'src/node_modules/fsevents/node_modules/tough-cookie/*',
            'src/node_modules/fsevents/node_modules/tough-cookie/lib/*',
            'src/node_modules/fsevents/node_modules/tunnel-agent/*',
            'src/node_modules/fsevents/node_modules/tweetnacl/*',
            'src/node_modules/fsevents/node_modules/uid-number/*',
            'src/node_modules/fsevents/node_modules/util-deprecate/*',
            'src/node_modules/fsevents/node_modules/uuid/*',
            'src/node_modules/fsevents/node_modules/uuid/bin/*',
            'src/node_modules/fsevents/node_modules/uuid/lib/*',
            'src/node_modules/fsevents/node_modules/uuid/test/*',
            'src/node_modules/fsevents/node_modules/verror/*',
            'src/node_modules/fsevents/node_modules/verror/examples/*',
            'src/node_modules/fsevents/node_modules/verror/lib/*',
            'src/node_modules/fsevents/node_modules/verror/tests/*',
            'src/node_modules/fsevents/node_modules/wide-align/*',
            'src/node_modules/fsevents/node_modules/wrappy/*',
            'src/node_modules/fsevents/src/*',
            'src/node_modules/function.name/*',
            'src/node_modules/function.name/dist/*',
            'src/node_modules/function.name/lib/*',
            'src/node_modules/git-package-json/*',
            'src/node_modules/git-package-json/lib/*',
            'src/node_modules/git-source/*',
            'src/node_modules/git-source/lib/*',
            'src/node_modules/git-up/*',
            'src/node_modules/git-up/example/*',
            'src/node_modules/git-up/lib/*',
            'src/node_modules/git-up/test/*',
            'src/node_modules/git-url-parse/*',
            'src/node_modules/git-url-parse/example/*',
            'src/node_modules/git-url-parse/lib/*',
            'src/node_modules/git-url-parse/test/*',
            'src/node_modules/glob-base/*',
            'src/node_modules/glob-parent/*',
            'src/node_modules/glob/*',
            'src/node_modules/globals/*',
            'src/node_modules/got/*',
            'src/node_modules/graceful-fs/*',
            'src/node_modules/gry/*',
            'src/node_modules/gry/lib/*',
            'src/node_modules/has-ansi/*',
            'src/node_modules/home-or-tmp/*',
            'src/node_modules/hosted-git-info/*',
            'src/node_modules/inflight/*',
            'src/node_modules/inherits/*',
            'src/node_modules/ini/*',
            'src/node_modules/invariant/*',
            'src/node_modules/is-arrayish/*',
            'src/node_modules/is-binary-path/*',
            'src/node_modules/is-buffer/*',
            'src/node_modules/is-buffer/test/*',
            'src/node_modules/is-builtin-module/*',
            'src/node_modules/is-dotfile/*',
            'src/node_modules/is-equal-shallow/*',
            'src/node_modules/is-extendable/*',
            'src/node_modules/is-extglob/*',
            'src/node_modules/is-finite/*',
            'src/node_modules/is-glob/*',
            'src/node_modules/is-number/*',
            'src/node_modules/is-posix-bracket/*',
            'src/node_modules/is-primitive/*',
            'src/node_modules/is-redirect/*',
            'src/node_modules/is-retry-allowed/*',
            'src/node_modules/is-ssh/*',
            'src/node_modules/is-ssh/example/*',
            'src/node_modules/is-ssh/lib/*',
            'src/node_modules/is-ssh/test/*',
            'src/node_modules/is-stream/*',
            'src/node_modules/isarray/*',
            'src/node_modules/isobject/*',
            'src/node_modules/iterate-object/*',
            'src/node_modules/iterate-object/example/*',
            'src/node_modules/iterate-object/lib/*',
            'src/node_modules/js-tokens/*',
            'src/node_modules/jsesc/*',
            'src/node_modules/jsesc/bin/*',
            'src/node_modules/jsesc/man/*',
            'src/node_modules/json5/*',
            'src/node_modules/json5/lib/*',
            'src/node_modules/kind-of/*',
            'src/node_modules/limit-it/*',
            'src/node_modules/limit-it/lib/*',
            'src/node_modules/lodash/*',
            'src/node_modules/lodash/fp/*',
            'src/node_modules/loose-envify/*',
            'src/node_modules/lowercase-keys/*',
            'src/node_modules/micromatch/*',
            'src/node_modules/micromatch/lib/*',
            'src/node_modules/minimatch/*',
            'src/node_modules/minimist/*',
            'src/node_modules/minimist/example/*',
            'src/node_modules/minimist/test/*',
            'src/node_modules/mkdirp/*',
            'src/node_modules/mkdirp/bin/*',
            'src/node_modules/mkdirp/examples/*',
            'src/node_modules/mkdirp/node_modules/*',
            'src/node_modules/mkdirp/node_modules/minimist/*',
            'src/node_modules/mkdirp/node_modules/minimist/example/*',
            'src/node_modules/mkdirp/node_modules/minimist/test/*',
            'src/node_modules/mkdirp/test/*',
            'src/node_modules/ms/*',
            'src/node_modules/nan/*',
            'src/node_modules/nan/doc/*',
            'src/node_modules/nan/tools/*',
            'src/node_modules/node-status-codes/*',
            'src/node_modules/noop6/*',
            'src/node_modules/noop6/lib/*',
            'src/node_modules/normalize-package-data/*',
            'src/node_modules/normalize-package-data/lib/*',
            'src/node_modules/normalize-path/*',
            'src/node_modules/number-is-nan/*',
            'src/node_modules/oargv/*',
            'src/node_modules/oargv/lib/*',
            'src/node_modules/obj-def/*',
            'src/node_modules/obj-def/lib/*',
            'src/node_modules/object-assign/*',
            'src/node_modules/object.omit/*',
            'src/node_modules/once/*',
            'src/node_modules/one-by-one/*',
            'src/node_modules/one-by-one/lib/*',
            'src/node_modules/os-homedir/*',
            'src/node_modules/os-tmpdir/*',
            'src/node_modules/output-file-sync/*',
            'src/node_modules/package-json-path/*',
            'src/node_modules/package-json-path/lib/*',
            'src/node_modules/package-json/*',
            'src/node_modules/package.json/*',
            'src/node_modules/package.json/lib/*',
            'src/node_modules/parse-glob/*',
            'src/node_modules/parse-json/*',
            'src/node_modules/parse-json/vendor/*',
            'src/node_modules/parse-url/*',
            'src/node_modules/parse-url/lib/*',
            'src/node_modules/path-is-absolute/*',
            'src/node_modules/pinkie-promise/*',
            'src/node_modules/pinkie/*',
            'src/node_modules/prepend-http/*',
            'src/node_modules/preserve/*',
            'src/node_modules/private/*',
            'src/node_modules/process-nextick-args/*',
            'src/node_modules/protocols/*',
            'src/node_modules/protocols/lib/*',
            'src/node_modules/r-json/*',
            'src/node_modules/r-json/lib/*',
            'src/node_modules/r-package-json/*',
            'src/node_modules/r-package-json/lib/*',
            'src/node_modules/randomatic/*',
            'src/node_modules/randomatic/node_modules/*',
            'src/node_modules/randomatic/node_modules/is-number/*',
            'src/node_modules/randomatic/node_modules/is-number/node_modules/*',
            'src/node_modules/randomatic/node_modules/is-number/node_modules/kind-of/*',
            'src/node_modules/randomatic/node_modules/kind-of/*',
            'src/node_modules/rc/*',
            'src/node_modules/rc/lib/*',
            'src/node_modules/rc/test/*',
            'src/node_modules/read-all-stream/*',
            'src/node_modules/readable-stream/*',
            'src/node_modules/readable-stream/doc/*',
            'src/node_modules/readable-stream/doc/wg-meetings/*',
            'src/node_modules/readable-stream/lib/*',
            'src/node_modules/readable-stream/lib/internal/*',
            'src/node_modules/readable-stream/lib/internal/streams/*',
            'src/node_modules/readdirp/*',
            'src/node_modules/readdirp/examples/*',
            'src/node_modules/readdirp/test/*',
            'src/node_modules/readdirp/test/bed/*',
            'src/node_modules/readdirp/test/bed/root_dir1/*',
            'src/node_modules/readdirp/test/bed/root_dir1/root_dir1_subdir1/*',
            'src/node_modules/readdirp/test/bed/root_dir2/*',
            'src/node_modules/regenerate/*',
            'src/node_modules/regenerator-runtime/*',
            'src/node_modules/regenerator-transform/*',
            'src/node_modules/regenerator-transform/lib/*',
            'src/node_modules/regenerator-transform/src/*',
            'src/node_modules/regex-cache/*',
            'src/node_modules/regexpu-core/*',
            'src/node_modules/regexpu-core/data/*',
            'src/node_modules/registry-auth-token/*',
            'src/node_modules/registry-auth-token/test/*',
            'src/node_modules/registry-url/*',
            'src/node_modules/regjsgen/*',
            'src/node_modules/regjsparser/*',
            'src/node_modules/regjsparser/bin/*',
            'src/node_modules/regjsparser/node_modules/*',
            'src/node_modules/regjsparser/node_modules/.bin/*',
            'src/node_modules/regjsparser/node_modules/jsesc/*',
            'src/node_modules/regjsparser/node_modules/jsesc/bin/*',
            'src/node_modules/regjsparser/node_modules/jsesc/man/*',
            'src/node_modules/remove-trailing-separator/*',
            'src/node_modules/repeat-element/*',
            'src/node_modules/repeat-string/*',
            'src/node_modules/repeating/*',
            'src/node_modules/safe-buffer/*',
            'src/node_modules/semver/*',
            'src/node_modules/semver/bin/*',
            'src/node_modules/set-immediate-shim/*',
            'src/node_modules/slash/*',
            'src/node_modules/sliced/*',
            'src/node_modules/source-map-support/*',
            'src/node_modules/source-map/*',
            'src/node_modules/source-map/dist/*',
            'src/node_modules/source-map/lib/*',
            'src/node_modules/spdx-correct/*',
            'src/node_modules/spdx-expression-parse/*',
            'src/node_modules/spdx-license-ids/*',
            'src/node_modules/string_decoder/*',
            'src/node_modules/string_decoder/lib/*',
            'src/node_modules/strip-ansi/*',
            'src/node_modules/strip-json-comments/*',
            'src/node_modules/supports-color/*',
            'src/node_modules/timed-out/*',
            'src/node_modules/tmp/*',
            'src/node_modules/tmp/lib/*',
            'src/node_modules/tmp/test/*',
            'src/node_modules/tmp/test/symlinkme/*',
            'src/node_modules/to-fast-properties/*',
            'src/node_modules/trim-right/*',
            'src/node_modules/typpy/*',
            'src/node_modules/typpy/lib/*',
            'src/node_modules/ul/*',
            'src/node_modules/ul/lib/*',
            'src/node_modules/unzip-response/*',
            'src/node_modules/url-parse-lax/*',
            'src/node_modules/user-home/*',
            'src/node_modules/util-deprecate/*',
            'src/node_modules/v8flags/*',
            'src/node_modules/validate-npm-package-license/*',
            'src/node_modules/wrappy/*',
            'templates/*']}

install_requires = \
['astor',
 'click',
 'eventlet',
 'flask',
 'flask-socketio',
 'future',
 'jinja2',
 'markdown',
 'msgpack-python']

setup(name='bowtie',
      version='0.7.0',
      description='Interactive dashboard toolkit.',
      author='Jacques Kvam',
      author_email='jwkvam+pypi@gmail.com',
      url='https://github.com/jwkvam/bowtie',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
     )
